<?php

/**
 * @file
 * flag_hide.admin.inc
 * Displays, submits and saves the form for the admin configuration page.
 */

/**
 * Menu callback for admin settings.
 */
function flag_hide_admin_config() {
  $form = array();
  $form['flag_hide_node'] = array(
    '#type' => 'fieldset',
    '#title' => t('Configuration for nodes'),
    '#description' => t('The node configuration options, if used, require the <a href="@href" target="project">Flag</a> module.', array(
      '@href' => url('http://drupal.org/project/flag')
    ))
  );
  $form['flag_hide_node']['flag_hide_method'] = array(
    '#type' => 'radios',
    '#title' => t('Method used to hide content'),
    '#default_value' => variable_get('flag_hide_method', FLAG_HIDE_METHOD_DEFAULT),
    '#options' => array(
      FLAG_HIDE_METHOD_DEFAULT => t('default, no files required'),
      FLAG_HIDE_METHOD_TEMPLATE_SUGGESTION => t('via the file <em>node--hide.tpl.php</em>, added to your theme'),
    ),
    '#description' => t("If you select the second method you must place <em>node--hide.tpl.php</em> in the same directory as your theme's node.tpl.php.<br/> <em>node--hide.tpl.php</em> may be empty or may contain some message with or without rendered variables."),
  );
  $form['flag_hide_node']['flag_hide_node_placeholder'] = array(
    '#type' => 'textfield',
    '#size' => 128,
    '#title' => t('Text to replace content body when hidden'),
    '#default_value' => variable_get('flag_hide_node_placeholder', FLAG_HIDE_NODE_PLACEHOLDER),
    '#description' => t('<strong>Example</strong>: "%msg"<br/> Some HTML tags are allowed. Blank out this field to show no trace of hidden content.', array(
      '%msg' => FLAG_HIDE_NODE_PLACEHOLDER)
    ),
    '#states' => array(
      'invisible' => array(
        'input[name="flag_hide_method"]' => array(
          'value' => FLAG_HIDE_METHOD_TEMPLATE_SUGGESTION,
        ),
      ),
    ),
  );
  $form['flag_hide_node']['flag_hide_node_title'] = array(
    '#type' => 'checkbox',
    '#title' => t('Hide title when associated content is hidden'),
    '#default_value' => variable_get('flag_hide_node_title', FALSE),
    '#description' => t('This applies to <em>node/*</em> pages.'),
  );

  $form['flag_hide_blocks'] = array(
    '#type' => 'fieldset',
    '#title' => t('Configuration for blocks'),
  );
  $form['flag_hide_blocks']['flag_hide_enable_block_hiding'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable hiding of empty blocks'),
    '#default_value' => variable_get('flag_hide_enable_block_hiding', FALSE),
    '#description' => t('This adds to each block configuration page a check box for removing title and HTML of blocks containing empty content, after flagging or otherwise.<br/> To activate this option on the block configuration form click the vertical tab <strong>Dynamic conditions</strong>.'),
  );

  $form['flag_hide_views'] = array(
    '#type' => 'fieldset',
    '#title' => t('Configuration for Views'),
  );
  $form['flag_hide_views']['flag_hide_empty_view_title'] = array(
    '#type' => 'checkbox',
    '#title' => t('Hide title of empty Views'),
    '#default_value' => variable_get('flag_hide_empty_view_title', FALSE),
    '#description' => t('This removes the title from any View with empty output.'),
  );

  $form['actions']['#type'] = 'actions';
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
  );
  $form['#submit'][] = 'flag_hide_admin_config_submit';
  $form['#theme'] = 'system_settings_form';
  return $form;
}

/**
 * Form submit handler for flag_hide_admin_config().
 *
 * @param array $form
 * @param array $form_state
 */
function flag_hide_admin_config_submit($form, &$form_state) {

  $allowed_html_tags = array('a', 'br', 'p', 'em', 'strong', 'cite', 'blockquote', 'code', 'ul', 'ol', 'li', 'dl', 'dt', 'dd');

  // Clear out the form from stuff, like buttons, we do not wish to save.
  form_state_values_clean($form_state);

  foreach ($form_state['values'] as $key => $value) {
    variable_set($key, filter_xss($value, $allowed_html_tags));
  }
  drupal_theme_rebuild();

  drupal_set_message(t('The configuration options have been saved.'));
}

